@@ -106,7 +106,7 @@ nsProbingState nsMBCSGroupProber::HandleData(const char *aBuf, unsigned int aLen
         } else if (st == eNotMe) {
             mIsActive[i] = false;
             mActiveNum--;
-            if (mActiveNum <= 0) {
+            if (mActiveNum == 0) {
                 mState = eNotMe;
                 break;
             }
@@ -121,7 +121,8 @@ nsProbingState nsMBCSGroupProber::HandleData(const char *aBuf, unsigned int aLen
 float nsMBCSGroupProber::GetConfidence(void)
 {
     unsigned int i;
-    float bestConf = 0.0, cf;
+    float bestConf = 0.0;
+    float cf;
 
     switch (mState) {
     case eFoundIt:
